TestCaseStatus

Enum TestCaseStatus 

pub enum TestCaseStatus {
    Success {
        flaky_runs: Vec<TestRerun>,
    },
    NonSuccess {
        kind: NonSuccessKind,
        message: Option<XmlString>,
        ty: Option<XmlString>,
        description: Option<XmlString>,
        reruns: NonSuccessReruns,
    },
    Skipped {
        message: Option<XmlString>,
        ty: Option<XmlString>,
        description: Option<XmlString>,
    },
}
Represents the success or failure of a test case.

Variants



Success

This test case passed.

Fields

flaky_runs: Vec<TestRerun>

Prior runs of the test. These are represented as flakyFailure or flakyError in the JUnit XML.



NonSuccess

This test case did not pass.

Fields

kind: NonSuccessKind

Whether this test case failed in an expected way (failure) or an unexpected way (error).

message: Option<XmlString>

The failure message.

ty: Option<XmlString>

The “type” of failure that occurred.

description: Option<XmlString>

The description of the failure.

This is serialized and deserialized from the text node of the element.

reruns: NonSuccessReruns

Test reruns and how they are serialized.

See NonSuccessReruns for details.



Skipped

This test case was not run.

Fields

message: Option<XmlString>

The skip message.

ty: Option<XmlString>

The “type” of skip that occurred.

description: Option<XmlString>

The description of the skip.

This is serialized and deserialized from the text node of the element.

Implementations

Source

impl TestCaseStatus

pub fn success() -> Self

Creates a new TestCaseStatus that represents a successful test.

pub fn non_success(kind: NonSuccessKind) -> Self

Creates a new TestCaseStatus that represents an unsuccessful test.

pub fn skipped() -> Self

Creates a new TestCaseStatus that represents a skipped test.

pub fn set_message(&mut self, message: impl Into<XmlString>) -> &mut Self

Sets the message. No-op if this is a success case.

pub fn set_type(&mut self, ty: impl Into<XmlString>) -> &mut Self

Sets the type. No-op if this is a success case.

pub fn set_description( &mut self, description: impl Into<XmlString>, ) -> &mut Self

Sets the description (text node). No-op if this is a success case.

pub fn add_rerun(&mut self, rerun: TestRerun) -> &mut Self

Adds a rerun or flaky run. No-op if this test was skipped.

For Success, reruns are always serialized as <flakyFailure>/<flakyError>. For NonSuccess, the rerun is added to the existing NonSuccessReruns variant.

pub fn add_reruns( &mut self, new_reruns: impl IntoIterator<Item = TestRerun>, ) -> &mut Self

Adds reruns or flaky runs. No-op if this test was skipped.

For Success, reruns are always serialized as <flakyFailure>/<flakyError>. For NonSuccess, reruns are added to the existing NonSuccessReruns variant.

pub fn set_rerun_kind(&mut self, kind: FlakyOrRerun) -> &mut Self

Sets the rerun kind for NonSuccess statuses.

This controls how reruns are serialized in JUnit XML. Use FlakyOrRerun::Flaky for <flakyFailure>/<flakyError> (the test exhibited flakiness), or FlakyOrRerun::Rerun for <rerunFailure>/<rerunError> (the default).

This is a no-op for Success (in which case reruns are always serialized as flaky) and Skipped (no reruns).